Documentation
¶
Index ¶
- func FindTagIndex(tags []*Tag, name string) int
- type Branch
- type Commit
- type Tag
- func FindTag(tags []*Tag, name string) *Tag
- func FindTagByHash(tags []*Tag, hash string) *Tag
- func GetTagRangeBetween(tags []*Tag, fromHash string, toHash string) []*Tag
- func GetTagRangeFrom(tags []*Tag, from string) []*Tag
- func GetTagRangeTo(tags []*Tag, from string) []*Tag
- func GetTags(path string) ([]*Tag, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FindTagIndex ¶
Types ¶
type Branch ¶
type Branch struct {
Commits []*Commit
}
func GetBranch ¶
GetBranch uses the internal go-git library to check out a branch and add all the commits in said branch as Commit objects.
func GetCurrentBranch ¶
type Tag ¶
type Tag struct {
Name string
Hash string
TagHash string
Tagger string
Email string
Message string
Time time.Time
}
func FindTagByHash ¶
func GetTagRangeBetween ¶
func GetTagRangeFrom ¶
func GetTagRangeTo ¶
Click to show internal directories.
Click to hide internal directories.